@@ -5,11 +5,11 @@ library(pbdSLAP, quiet = TRUE)
 init()
 
 slap.init.grid(2, 2, ictxt = 0)
-comm.print(.__grid_info_0, all.rank = TRUE)
+comm.print(.pbdSLAPEnv$.__grid_info_0, all.rank = TRUE)
 slap.exit.grid(0)
 
 slap.init.grid(2, 3, ictxt = 1)
-comm.print(.__grid_info_1, all.rank = TRUE)
+comm.print(.pbdSLAPEnv$.__grid_info_1, all.rank = TRUE)
 slap.exit.grid(1)
 
 slap.finalize()
